(function($){

    "use strict";

    var AutoGoogle_NewsAction = {

        init: function()
        {
            // Document ready.
            $( document ).ready( AutoGoogle_NewsAction._stickyHeader() );
            $( document ).ready( AutoGoogle_NewsAction._loadPopup() );
            $( document ).ready( AutoGoogle_NewsAction._mobileSelect() );
            $( document ).ready( AutoGoogle_NewsAction._rangeSlider() );
            $( document ).ready( AutoGoogle_NewsAction._mainSelect() );
            $( document ).ready( AutoGoogle_NewsAction._postSelect() );
            $( document ).ready( AutoGoogle_NewsAction._typeSelect() );
            $( document ).ready( AutoGoogle_NewsAction._authorSelect() );
            $( document ).ready( AutoGoogle_NewsAction._categorySelect() );

            this._bind();
        },

        /**
         * Binds events for the Auto Google News Action.
         *
         * @since 1.0.0
         * @access private
         * @method _bind
         */
        _bind: function()
        {
            $( document ).on('click', '.google_news-vertical-tab a', AutoGoogle_NewsAction._switchTabs );
            $( document ).on('keyup', '#google_news-search', AutoGoogle_NewsAction._searchSuggest );
            $( document ).on('click', '.google_news-keyword-selected', AutoGoogle_NewsAction._selectKeyword );
            $( document ).on('click', '#google_news-campaign-save', AutoGoogle_NewsAction._saveCampaign );
            $( document ).on('click', '#google_news-campaign-publish', AutoGoogle_NewsAction._publishCampaign );
            $( document ).on('click', '.google_news-run-campaign-button', AutoGoogle_NewsAction._runCampaign );

            $( document ).on('click', '.sui-tab-item', AutoGoogle_NewsAction._switchSuiTabs );
            $( document ).on('click', '.nav-tab', AutoGoogle_NewsAction._switchWelcomeTabs );

            $( document ).ready( AutoGoogle_NewsAction._languageSelector() );

        },


        /**
         * Language Selector
         *
         */
         _languageSelector: function( ) {
            $('.google-news-init-language-selector').click(function(e) {
                e.preventDefault();
                e.stopPropagation();
                /* api type expanded */
                $(this).toggleClass('expanded');

                /* set from language value */
                //var translator_from_language = $('#'+$(e.target).attr('for'));
                var language = $(this).find('#'+$(e.target).attr('for'));
                console.log(language);
                language.prop('checked',true);
            });
        },

        /**
         * Switch Tabs
         *
         */
        _switchTabs: function( event ) {

            event.preventDefault();

            var tab = '#' + $(this).data('nav');

            $('.google_news-vertical-tab').removeClass('current');
            $(this).parent().addClass('current');

            $('.google_news-box-tab').removeClass('active');
            $('.google_news-box-tabs').find(tab).addClass('active');

        },

        /**
         * Switch Welcome Tabs
         *
         */
         _switchWelcomeTabs: function( event ) {

            event.preventDefault();
            var tab = '#' + $(this).data('nav');

            $('.nav-tab').removeClass('nav-tab-active');
            $(this).addClass('nav-tab-active');

            $('.nav-container').removeClass('active');
            $('.robot-welcome-tabs').find(tab).addClass('active');

        },

        /**
         * Switch Sui Tabs
         *
         */
        _switchSuiTabs: function( event ) {

            event.preventDefault();

            //console.log('clicked');

            var tab = '#' + $(this).data('nav');

            console.log(tab);

            $('.sui-tab-item').removeClass('active');
            $(this).addClass('active');

            $('.sui-tab-content').removeClass('active');
            $('.sui-tabs-content').find(tab).addClass('active');


        },

        /**
         * Search Suggest
         *
         */
        _searchSuggest: function( ) {

            var term = $(this).val();

            $.ajax({
                    url  : 'https://clients1.google.com/complete/search',
                    type : 'GET',
                    dataType: 'jsonp',
                    data: {
                        q: term,
                        nolabels: 't',
                        client: 'hp',
                        ds: ''
                    },
                })
                .fail(function( jqXHR ){
                    console.log( jqXHR.status + ' ' + jqXHR.responseText);
                })
                .done(function ( data ) {

                    var result = [];

                    $.each( data[1], function( key, value ) {
                        result[key] = value[0];
                    });

                    var template = wp.template('google_news-search-results');

                    jQuery('.search-result-list').show().html(template( result ));

                });

        },

        /**
         * Select Keyword
         *
         */
        _selectKeyword: function( event ) {

            event.preventDefault();

            var keyword = $(this).data('keyword');
            var parsed = keyword.replace(/(<([^>]+)>)/ig,"");

            $('#google_news-selected-keywords').val(function(i, text) {
                if(text.length === 0){
                    return text +  parsed;
                }else{
                    return text + ', '+ parsed;
                }
            });


        },

        /**
         * Save Campaign
         *
         */
        _saveCampaign: function( ) {

            // set post form data
            var formdata = $('.google_news-campaign-form').serializeArray();
            var fields = {};
            $(formdata ).each(function(index, obj){
                fields[obj.name] = obj.value;
            });
            fields['campaign_status'] = 'draft';
            fields['update_frequency'] = $('.range-slider__value').text();
            fields['update_frequency_unit'] = $('#google_news-field-unit-button').val();
            fields['google_news_post_status'] = $('#google_news-post-status').val();
            fields['google_news_post_type'] = $('#google_news-post-type').val();
            fields['google_news_post_author'] = $('#google_news-post-author').val();

            // set selected category data
            var select_category_data = $('.google_news-category-multi-select').select2('data');
            var selected_category = select_category_data.map(function (el) {
                return el.id;
            });
            fields['google_news-post-category'] = selected_category;

            // set selected tag data
            var select_tag_data = $('.google_news-tag-multi-select').select2('data');
            var selected_tag = select_tag_data.map(function (el) {
                return el.id;
            });
            console.log(selected_tag);
            fields['google_news-post-tag'] = selected_tag;

            $.ajax({
                    url  : Auto_Google_News_Data.ajaxurl,
                    type : 'POST',
                    dataType: 'json',
                    data : {
                        action       : 'auto_google_news_save_campaign',
                        fields_data  : fields,
                        _ajax_nonce  : Auto_Google_News_Data._ajax_nonce


                    },
                    beforeSend: function() {

                        $('.google_news-status-changes').html('<ion-icon name="reload-circle"></ion-icon></ion-icon>Saving');

                    },
                })
                .fail(function( jqXHR ){
                    console.log( jqXHR.status + ' ' + jqXHR.responseText);
                })
                .done(function ( options ) {
                    if( false === options.success ) {
                        console.log(options);
                    } else {
                        console.log(options.data);
                        $( "input[name='campaign_id']" ).val(options.data);


                        // update campaign status
                        $('.google_news-tag').html('draft');
                        $('.google_news-tag').removeClass('google_news-tag-published');
                        $('.google_news-tag').addClass('google_news-tag-draft');

                        // update campaign save icon status
                        $('.google_news-status-changes').html('<ion-icon class="google_news-icon-saved" name="checkmark-circle"></ion-icon>Saved');

                        // update campaign button text
                        $('.campaign-save-text').text('save draft');
                        $('.campaign-publish-text').text('publish');

                        //update page url with campaign id
                        var campaign_url = Auto_Google_News_Data.wizard_url+ '&id=' + options.data + '&source=' + fields['google_news_selected_source'];
                        window.history.replaceState('','',campaign_url);
                    }
                });

        },

        /**
         * Publish Campaign
         *
         */
        _publishCampaign: function( ) {


            var formdata = $('.google_news-campaign-form').serializeArray();
            var fields = {};
            $(formdata ).each(function(index, obj){
                fields[obj.name] = obj.value;
            });
            fields['campaign_status'] = 'publish';
            fields['update_frequency'] = $('.range-slider__value').text();
            fields['update_frequency_unit'] = $('#google_news-field-unit-button').val();
            fields['google_news_post_status'] = $('#google_news-post-status').val();
            fields['google_news_post_type'] = $('#google_news-post-type').val();
            fields['google_news_post_author'] = $('#google_news-post-author').val();

            // set selected category data
            var select_category_data = $('.google_news-category-multi-select').select2('data');
            var selected_category = select_category_data.map(function (el) {
                return el.id;
            });
            fields['google_news-post-category'] = selected_category;

            // set selected tag data
            var select_tag_data = $('.google_news-tag-multi-select').select2('data');
            var selected_tag = select_tag_data.map(function (el) {
                return el.id;
            });
            fields['google_news-post-tag'] = selected_tag;

            console.log(fields);

            $.ajax({
                    url  : Auto_Google_News_Data.ajaxurl,
                    type : 'POST',
                    dataType: 'json',
                    data : {
                        action       : 'auto_google_news_save_campaign',
                        fields_data  : fields,
                        _ajax_nonce  : Auto_Google_News_Data._ajax_nonce,


                    },
                    beforeSend: function() {

                        $('.google_news-status-changes').html('<ion-icon name="reload-circle"></ion-icon></ion-icon>Saving');

                    },
                })
                .fail(function( jqXHR ){
                    console.log( jqXHR.status + ' ' + jqXHR.responseText);
                })
                .done(function ( options ) {
                    if( false === options.success ) {
                        console.log(options);
                    } else {
                        console.log(options);
                        $( "input[name='campaign_id']" ).val(options.data);

                        // update campaign tag status
                        $('.google_news-tag').html('published');
                        $('.google_news-tag').removeClass('google_news-tag-draft');
                        $('.google_news-tag').addClass('google_news-tag-published');

                        // update campaign save icon status
                        $('.google_news-status-changes').html('<ion-icon class="google_news-icon-saved" name="checkmark-circle"></ion-icon>Saved');

                        // update campaign button text
                        $('.campaign-save-text').text('unpublish');
                        $('.campaign-publish-text').text('update');

                        //update page url with campaign id
                        var campaign_url = Auto_Google_News_Data.wizard_url+ '&id=' + options.data + '&source=' + fields['google_news_selected_source'];
                        window.history.replaceState('','',campaign_url);



                    }
                });

        },

        /**
         * Run Campaign
         *
         */
        _runCampaign: function( ) {

            var fields = {};
            fields['campaign_id'] = $( "input[name='campaign_id']" ).val();

            $.ajax({
                    url  : Auto_Google_News_Data.ajaxurl,
                    type : 'POST',
                    dataType: 'json',
                    data : {
                        action       : 'auto_google_news_run_campaign',
                        fields_data  : fields,
                        _ajax_nonce  : Auto_Google_News_Data._ajax_nonce,
                    },
                    beforeSend: function() {
                      $('.google_news-box-footer').hide();
                      $('.google_news-campaign-popup-body').html('<div class="google_news-campaign-running"><div class="loader" id="loader-1"></div><span>running now...</span><div>');
                    },
                })
                .fail(function( jqXHR ){
                    console.log( jqXHR.status + ' ' + jqXHR.responseText);
                })
                .done(function ( option ) {
                    if( false === option.success ) {
                        console.log(option);
                        $('.google_news-campaign-popup-body').html(option.data);
                    } else {
                        setTimeout(function(){

                            $('.google_news-campaign-popup-body').html('Running Log:<br>');
                            $.each(option.data, function(index, value) {
                                $('.google_news-campaign-popup-body').append(value);
                                $('.google_news-campaign-popup-body').append('<br>');
                            });
                            $('.google_news-campaign-popup-body').append('Finished');

                            $('.google_news-box-footer').show();

                        },3000);

                   }

                });

        },


        /**
         * Sticky Header
         *
         */
        _stickyHeader: function( ) {

                //===== Sticky

                $(window).on('scroll',function(event) {
                    var scroll = $(window).scrollTop();
                    if (scroll < 245) {
                         $(".google_news-box-sticky").removeClass("google_news-is-sticky");
                    }else{
                          $(".google_news-box-sticky").addClass("google_news-is-sticky");
                    }
                });

        },

        /**
         * Load Popup
         *
         */
        _loadPopup: function( ) {

            $('.open-popup-campaign').magnificPopup({
                type:'inline',
                midClick: true, // Allow opening popup on middle mouse click. Always set it to true if you don't provide alternative source in href.
                // Delay in milliseconds before popup is removed
                removalDelay: 300,

                // Class that is added to popup wrapper and background
                // make it unique to apply your CSS animations just to this exact popup
                callbacks: {
                    beforeOpen: function() {
                        this.st.mainClass = this.st.el.attr('data-effect');
                    }
                },
            });

        },

        /**
         * Mobile Select
         *
         */
        _mobileSelect: function( ) {

            // onClick new options list of new select
            var newOptions = $('.google_news-vertical-tabs > li');
            newOptions.on('click', function(){
                $('.google_news-select-content').text($(this).text());
                $('.google_news-vertical-tabs > li').removeClass('selected');
                $(this).addClass('selected');
            });

            var aeDropdown = $('.google_news-sidenav');
            aeDropdown.on('click', function(){
                $('.google_news-vertical-tabs').toggleClass('google_news-sidenav-hide-md');
            });

        },

        /**
         * Range Slider
         *
         */
        _rangeSlider: function( ) {

            var slider = $('.range-slider'),
                range = $('.range-slider__range'),
                value = $('.range-slider__value');

            slider.each(function(){

                value.each(function(){
                    var value = $(this).prev().attr('value');
                    $(this).html(value);
                });

                range.on('input', function(){
                    $(this).next(value).html(this.value);
                });
            });

        },

        /**
         * Main Select
         *
         */
        _mainSelect: function( ) {

            // onClick new options list of new select
            var newOptions = $('.list-results > li');
            newOptions.on('click', function(){
                $('.list-value').text($(this).text());
                $('.list-value').val($(this).text());
                $('.list-results > li').removeClass('selected');
                $(this).addClass('selected');
            });

            var aeDropdown = $('.select-list-container');
            aeDropdown.on('click', function(){
                $('.list-results').toggleClass('google_news-sidenav-hide-md');
            });

            var google_newsDropdown = $('.dropdown-handle');
            google_newsDropdown.on('click', function(){
                $('.list-results').toggleClass('google_news-sidenav-hide-md');
            });



        },

        /**
         * Post Select
         *
         */
        _postSelect: function( ) {

            // onClick new options list of new select
            var newOptions = $('.post-list-results > li');
            newOptions.on('click', function(){
                $('.post-list-value').text($(this).text());
                $('.post-list-value').val($(this).text());
                $('.post-list-results > li').removeClass('selected');
                $(this).addClass('selected');
            });

            var aeDropdown = $('.post-select-list-container');
            aeDropdown.on('click', function(){
                $('.post-list-results').toggleClass('google_news-sidenav-hide-md');
            });

            var google_newsDropdown = $('.post-dropdown-handle');
            google_newsDropdown.on('click', function(){
                $('.post-list-results').toggleClass('google_news-sidenav-hide-md');
            });
        },

        /**
         * Type Select
         *
         */
        _typeSelect: function( ) {

            // onClick new options list of new select
            var newOptions = $('.type-list-results > li');
            newOptions.on('click', function(){
                $('.type-list-value').text($(this).text());
                $('.type-list-value').val($(this).text());
                $('.type-list-results > li').removeClass('selected');
                $(this).addClass('selected');
            });

            var aeDropdown = $('.type-select-list-container');
            aeDropdown.on('click', function(){
                $('.type-list-results').toggleClass('google_news-sidenav-hide-md');

            });

            var google_newsDropdown = $('.type-dropdown-handle');
            google_newsDropdown.on('click', function(){
                $('.type-list-results').toggleClass('google_news-sidenav-hide-md');
            });

        },

        /**
         * Author Select
         *
         */
        _authorSelect: function( ) {

            // onClick new options list of new select
            var newOptions = $('.author-list-results > li');
            newOptions.on('click', function(){
                $('.author-list-value').text($(this).text());
                $('.author-list-value').val($(this).text());
                $('.author-list-results > li').removeClass('selected');
                $(this).addClass('selected');
            });

            var aeDropdown = $('.author-select-list-container');
            aeDropdown.on('click', function(){
                $('.author-list-results').toggleClass('google_news-sidenav-hide-md');

            });

            var google_newsDropdown = $('.author-dropdown-handle');
            google_newsDropdown.on('click', function(){
                $('.author-list-results').toggleClass('google_news-sidenav-hide-md');
            });

        },

        /**
         * Category Select
         *
         */
        _categorySelect: function( ) {

            // Categories Select2
            $(".google_news-category-multi-select").select2({
                placeholder: "Select your post categories here", //placeholder
                allowClear: true
            });

            // Tags Select2
            $(".google_news-tag-multi-select").select2({
                placeholder: "Select your post tags here", //placeholder
                allowClear: true
            });

        },


    };

    /**
     * Initialize AutoGoogle_NewsAction
     */
    $(function(){
        AutoGoogle_NewsAction.init();
    });

})(jQuery);
