<?php
/**
 * Plugin Name: Auto Google News
 * Plugin URI: http://wphobby.com
 * Description: Auto Google News
 * Version: 1.0.9
 * Author: 20script
 * Author URI: https://www.20script.ir
 *
 * @package Auto Google News
 */

if ( ! defined( 'ABSPATH' ) ) {
    exit;
} // Exit if accessed directly

/**
 * Set constants
 */
if ( ! defined( 'AUTO_GOOGLE_NEWS_DIR' ) ) {
    define( 'AUTO_GOOGLE_NEWS_DIR', plugin_dir_path(__FILE__) );
}

if ( ! defined( 'AUTO_GOOGLE_NEWS_URL' ) ) {
    define( 'AUTO_GOOGLE_NEWS_URL', plugin_dir_url(__FILE__) );
}

if ( ! defined( 'AUTO_GOOGLE_NEWS_VERSION' ) ) {
    define( 'AUTO_GOOGLE_NEWS_VERSION', '1.0.9' );
}

if ( ! defined( 'AUTO_GOOGLE_NEWS_FILE' ) ) {
	define( 'AUTO_GOOGLE_NEWS_FILE', __FILE__ );
}

/**
 * Class Auto_Google_News
 *
 * Main class. Initialize plugin
 *
 * @since 1.0.0
 */
if ( ! class_exists( 'Auto_Google_News' ) ) {
    /**
     * Auto_Google_News
     */
    class Auto_Google_News {

        const DOMAIN = 'auto-google-news';

        /**
         * Instance of Auto_Google_News
         *
         * @since  1.0.0
         * @var (Object) Auto_Google_News
         */
        private static $_instance = null;

        /**
         * Get instance of Auto_Google_News
         *
         * @since  1.0.0
         *
         * @return object Class object
         */
        public static function get_instance() {
            if ( ! isset( self::$_instance ) ) {
                self::$_instance = new self;
            }
            return self::$_instance;
        }

        /**
         * Constructor
         *
         * @since  1.0.0
         */
        private function __construct() {
            $this->includes();
            $this->init();
        }

        /**
         * Load plugin files
         *
         * @since 1.0
         */
        private function includes() {
            // Core files.
            require_once AUTO_GOOGLE_NEWS_DIR . '/includes/class-core.php';
            require_once AUTO_GOOGLE_NEWS_DIR . '/includes/class-addon-loader.php';
        }


        /**
         * Init the plugin
         *
         * @since 1.0.0
         */
        private function init() {
            // Initialize plugin core
            $this->auto_google_news = Auto_Google_News_Core::get_instance();

            // Create tables
            $this->create_tables();

            // Initial Schedule Class for WP Cron Jobs
            Auto_Google_News_Schedule::get_instance();

            add_action( 'admin_init', array( $this, 'welcome' ) );

            /**
             * Triggered when plugin is loaded
             */
            do_action( 'auto_google_news_loaded' );

            add_action('current_screen', array( $this, 'current_screen_action') );

        }

        /** Redirect to welcome page when activation */
		public function welcome() {
            $page_url = 'admin.php?page=auto-google-news-welcome';
            if ( ! get_transient( '_auto_google_news_activation_redirect' ) ) {
                return;
            }
            delete_transient( '_auto_google_news_activation_redirect' );
            wp_safe_redirect( admin_url( $page_url ) );
            exit;
		}

        /**
         * @since 1.0.0
         */
        public static function create_tables() {
            global $wpdb;
            $wpdb->hide_errors();

            $table_schema = [
                "CREATE TABLE IF NOT EXISTS `{$wpdb->prefix}auto_google_news_logs` (
                `id` int(11) unsigned NOT NULL AUTO_INCREMENT,
                `camp_id` int(11) DEFAULT NULL,
                `level` ENUM('log','info','warn','error','success') NOT NULL DEFAULT 'log',
                `message` text DEFAULT NULL,
                `created` DECIMAL(16, 6) NOT NULL,
                PRIMARY KEY (`id`)
            )  CHARACTER SET utf8 COLLATE utf8_general_ci;",
            ];
            require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
            foreach ( $table_schema as $table ) {
                dbDelta( $table );
            }
        }

        /**
        * Current screen action
        *
        * @since 1.0.1
        * @return void
        */
        public function current_screen_action() {
            $screen = get_current_screen();
            $where = array(
                'toplevel_page_auto-google-news',
                'auto-google-news_page_auto-google-news-campaign',
                'auto-google-news_page_auto-google-news-integrations',
                'auto-google-news_page_auto-google-news-wizard',
                'auto-google-news_page_auto-google-news-campaign-wizard',
                'auto-google-news_page_auto-google-news-logs',
                'auto-google-news_page_auto-google-news-settings',
                'auto-google-news_page_auto-google-news-upgrade',
                'auto-google-news_page_auto-google-news-welcome',
                'auto-google-news_page_auto-google-news-addons'
            );

            $enable_notice = true;
            if ( in_array($screen->base, $where) ) {
                $enable_notice = false;
            };

            if($enable_notice){
                // add_action( 'admin_notices', array( $this, 'display_admin_notice' ) );
                // add_action( 'admin_enqueue_scripts', array( $this, 'enqueue_notice_scripts' ));
            }else{
                wp_enqueue_style( 'auto-google-news-hide-style', AUTO_GOOGLE_NEWS_URL . 'assets/css/hide.css', array(), AUTO_GOOGLE_NEWS_VERSION, false );
            }
        }



    }
}

if ( ! function_exists( 'auto_google_news' ) ) {
    function auto_google_news() {
        return Auto_Google_News::get_instance();
    }

    /**
     * Init the plugin and load the plugin instance
     *
     * @since 1.0.0
     */
    add_action( 'plugins_loaded', 'auto_google_news' );
}

/**
* Plugin install hook
*
* @since 1.8.0
* @return void
*/
if ( ! function_exists( 'auto_google_news_install' ) ) {
    function auto_google_news_install(){
        // Hook for plugin install.
		do_action( 'auto_google_news_install' );

		/*
		* Set current version.
		*/
		update_option( 'auto_google_news_version_pro', AUTO_GOOGLE_NEWS_VERSION );

        set_transient( '_auto_google_news_activation_redirect', 1 );
    }
}

// When activated, trigger install method.
register_activation_hook( AUTO_GOOGLE_NEWS_FILE, 'auto_google_news_install' );