<?php
/**
 * Auto_Google_News Class
 *
 * Plugin Core Class
 *
 * @since  1.0.0
 * @package Auto Google News
 */

if ( ! defined( 'ABSPATH' ) ) {
    exit;
} // Exit if accessed directly

if ( ! class_exists( 'Auto_Google_News_Core' ) ) :

   class Auto_Google_News_Core {

       /**
       * @var Auto_Google_News_Admin
       */
       public $admin;

       /**
       * Store modules objects
       *
       * @var array
       */
       public $modules = array();

       /**
       * Store forms objects
       *
       * @var array
       */
       public $forms = array();

       /**
       * Store fields objects
       *
       * @var array
       */
       public $fields = array();

       /**
       * Plugin instance
       *
       * @var null
       */
       private static $instance = null;

       /**
       * Return the plugin instance
       *
       * @since 1.0.0
       * @return Auto_Google_News_Core
       */
       public static function get_instance() {
        if ( is_null( self::$instance ) ) {
            self::$instance = new self();
        }

        return self::$instance;
    }

       /**
       * Auto_Google_News_Core constructor.
       *
       * @since 1.0
       */
       public function __construct() {
           // Include all necessary files
           $this->includes();


           if ( is_admin() ) {
              // Initialize admin core
              $this->admin = new Auto_Google_News_Admin();
           }

           // Get enabled modules
           $modules       = new Auto_Google_News_Modules();
           $this->modules = $modules->get_modules();

           // Add integrations and logs page
           if ( is_admin() ) {
            $this->admin->add_welcome_page();
           }
       }

       /**
       * Includes
       *
       * @since 1.0.0
       */
       private function includes() {
           // Library
           if ( ! class_exists( 'simple_html_dom_node' ) ){
             require_once AUTO_GOOGLE_NEWS_DIR . 'includes/library/simple_html_dom.php';
           }


           // Helpers
           require_once AUTO_GOOGLE_NEWS_DIR . '/includes/helpers/helper-core.php';
           require_once AUTO_GOOGLE_NEWS_DIR . '/includes/helpers/helper-forms.php';
           require_once AUTO_GOOGLE_NEWS_DIR . '/includes/helpers/helper-fields.php';
           require_once AUTO_GOOGLE_NEWS_DIR . '/includes/helpers/helper-addons.php';


           // Model
           require_once AUTO_GOOGLE_NEWS_DIR . '/includes/model/class-base-form-model.php';
           require_once AUTO_GOOGLE_NEWS_DIR . '/includes/model/class-custom-form-model.php';


           // Jobs
           require_once AUTO_GOOGLE_NEWS_DIR . '/includes/jobs/abstract-class-job.php';
           require_once AUTO_GOOGLE_NEWS_DIR . '/includes/jobs/class-google-news-job.php';
           require_once AUTO_GOOGLE_NEWS_DIR . '/includes/jobs/class-search-job.php';

           // Classes
           require_once AUTO_GOOGLE_NEWS_DIR . '/includes/class-loader.php';
           require_once AUTO_GOOGLE_NEWS_DIR . '/includes/class-modules.php';
           require_once AUTO_GOOGLE_NEWS_DIR . '/includes/class-log.php';
           require_once AUTO_GOOGLE_NEWS_DIR . '/includes/class-schedule.php';


           if ( is_admin() ) {
               require_once AUTO_GOOGLE_NEWS_DIR . '/admin/abstracts/class-admin-page.php';
               require_once AUTO_GOOGLE_NEWS_DIR . '/admin/abstracts/class-admin-module.php';
               require_once AUTO_GOOGLE_NEWS_DIR . '/admin/classes/class-admin.php';
           }

       }

   }

endif;
